prontonet-py
============

.. image:: https://badge.fury.io/py/prontonet.svg
    :target: https://badge.fury.io/py/prontonet

.. image:: https://img.shields.io/github/license/Naereen/StrapDown.js.svg
   :target: https://github.com/dgalus/prontonet-py/blob/master/LICENSE

.. image:: https://badgen.net/badge/Open%20Source%20%3F/Yes%21/blue?icon=github
   :target: https://github.com/dgalus/prontonet-py/

.. image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/

| Python library for ProntoNet family SDK v2.5.4.

SDK documentation for C/C++ is available here: https://www.prodys.net/download/1231/.


Source Code
-----------
https://github.com/dgalus/prontonet-py

PyPI package
------------
https://pypi.org/project/prontonet/

Documentation
-------------
https://dgalus.github.io/prontonet-py/

Documentation can be also found in the `docs/` directory.

Installation
------------
    python -m pip install prontonet

Author
------
dgalus / avc <avcsec@protonmail.com>
